.. _code_doc:

Code Documentation
==================

Welcome to the package documentation of ProjectQ. You may now browse through the entire documentation and discover the capabilities of the ProjectQ framework.

For a detailed documentation of a subpackage or module, click on its name below:

.. toctree::
    :maxdepth: 1
    :titlesonly:

    _doc_gen/projectq.backends
    _doc_gen/projectq.cengines
    _doc_gen/projectq.libs
    _doc_gen/projectq.meta
    _doc_gen/projectq.ops
    _doc_gen/projectq.setups
    _doc_gen/projectq.types
